@@ -2,18 +2,13 @@ import ast
 import json
 import logging
 import platform
-from datetime import datetime
 from aiortc import VideoStreamTrack
 from av import VideoFrame
-import pyaudio as pyaudio
+# import pyaudio as pyaudio
 import socketio
-from aiortc import RTCPeerConnection, RTCRtpSender, RTCConfiguration, RTCIceServer, RTCSessionDescription, \
-    MediaStreamTrack
+from aiortc import RTCPeerConnection, RTCRtpSender, RTCConfiguration, RTCIceServer, RTCSessionDescription
 from aiortc.contrib.media import MediaPlayer, MediaRelay, MediaBlackhole
-import subprocess
-from queue import Queue
-import cv2
-from random import random
+
 import asyncio
 import collections
 import time
@@ -23,11 +18,11 @@ relay = None
 webcam = None
 import numpy as np
 
-p = pyaudio.PyAudio()
-stream = p.open(format=pyaudio.paFloat32,
-                channels=1,
-                rate=48000,
-                output=True)
+# p = pyaudio.PyAudio()
+# stream = p.open(format=pyaudio.paFloat32,
+#                 channels=1,
+#                 rate=48000,
+#                 output=True)
 
 video_tracklist = []
 
@@ -113,33 +108,33 @@ def force_codec(pc, sender, forced_codec):
     )
 
 
-class MicStreamTrack(MediaStreamTrack):
-    """
-    An audio stream object for the mic audio from the client
-    """
-    kind = "audio"
-
-    def __init__(self, track):
-        super().__init__()
-        self.track = track
-        self._logger = logging.getLogger(__name__)
-
-    async def recv(self):
-        self._logger.error("mic recv()")
-
-        # Get a new PyAV frame
-        frame = await self.track.recv()
-
-        # Convert to float32 numpy array
-        floatArray = frame.to_ndarray(format="float32")
-        samples = np.sin(np.arange(50000) / 20)
-        # stream.write(floatArray.tostring())
-        stream.write(samples.astype(np.float32).tostring())
-
-        # Put these samples into the mic queue
-        # micSampleQueue.put_nowait(floatArray)
-
-        self._logger.error("Put {} samples to mic queue".format(len(floatArray)))
+# class MicStreamTrack(MediaStreamTrack):
+#     """
+#     An audio stream object for the mic audio from the client
+#     """
+#     kind = "audio"
+#
+#     def __init__(self, track):
+#         super().__init__()
+#         self.track = track
+#         self._logger = logging.getLogger(__name__)
+#
+#     async def recv(self):
+#         self._logger.error("mic recv()")
+#
+#         # Get a new PyAV frame
+#         frame = await self.track.recv()
+#
+#         # Convert to float32 numpy array
+#         floatArray = frame.to_ndarray(format="float32")
+#         samples = np.sin(np.arange(50000) / 20)
+#         # stream.write(floatArray.tostring())
+#         stream.write(samples.astype(np.float32).tostring())
+#
+#         # Put these samples into the mic queue
+#         # micSampleQueue.put_nowait(floatArray)
+#
+#         self._logger.error("Put {} samples to mic queue".format(len(floatArray)))
 
 
 class GSPeerConnectionBroadcasterUniversal:
@@ -310,11 +305,11 @@ class GSPeerConnectionBroadcasterUniversalNew:
                 if track.kind == "video":
                     mediablackhole = MediaBlackhole()
                     mediablackhole.addTrack(track)
-                if track.kind == "audio":
-                    micTrack = MicStreamTrack(track)
-                    blackHole = MediaBlackhole()
-                    blackHole.addTrack(micTrack)
-                    await blackHole.start()
+                # if track.kind == "audio":
+                #     micTrack = MicStreamTrack(track)
+                #     blackHole = MediaBlackhole()
+                #     blackHole.addTrack(micTrack)
+                #     await blackHole.start()
 
             async def on_iceconnectionstatechange():
                 print("ICE connection state is ", self.peerConnections[id].iceConnectionState)
