@@ -1,5 +1,6 @@
 import ast
 import asyncio
+import threading
 import json
 import logging
 from strenum import StrEnum
@@ -270,8 +271,6 @@ class FrameBufferThread(Thread):
             buf = self.nal_queue.get()
             if buf is not None or buf:
                 self.onframe(self.gsdbs, self.target, buf, self.framerate)
-
-
 class GSMediaConsumer:
 
     def __init__(self, gsdbs, target, onframe):
@@ -316,3 +315,80 @@ class GSMediaConsumer:
             if task is not None:
                 task.cancel()
         self.__tracks = {}
+
+class FrameBufferThreadAsync():
+    def __init__(self, gsdbs, target, onframe):
+        self.gsdbs = gsdbs
+        self.logger = logging.getLogger(__name__)
+        self.logger.debug("Starting Buffer")
+        self.target = target
+        self.onframe = onframe
+        self.framerate = 0
+        self.nal_queue = Queue(3)
+
+    async def write(self, frame, framerate=0):
+        self.framerate = framerate
+        if not self.nal_queue.full():
+            self.nal_queue.put(frame)
+
+    async def run(self):
+        while True:
+            buf = self.nal_queue.get()
+            if buf is not None or buf:
+                await self.onframe(self.gsdbs, self.target, buf, self.framerate)
+
+
+class GSMediaConsumerAsync:
+
+    def __init__(self, gsdbs, target, onframe):
+        self.__tracks = {}
+        self.gsdbs = gsdbs
+        self.target = target
+        self.onframe = onframe
+        self.nal_queue = Queue(3)
+        self.broadcastthread = FrameBufferThreadAsync(self.gsdbs, self.target, self.onframe)
+        loop = asyncio.get_event_loop()
+        self.bthread = loop.create_task(self.startBroadcastTrack())
+        # t2 = threading.Thread(target=asyncio.run, args=(,))
+        # t2.start()
+
+    async def startBroadcastTrack(self):
+        await self.broadcastthread.run()
+
+    def addTrack(self, track):
+        if track not in self.__tracks:
+            self.__tracks[track] = None
+
+    async def start(self):
+        """
+        Start discarding media.
+        """
+        for track, task in self.__tracks.items():
+            if task is None:
+                # self.startProcessing(task)
+                # _thread = threading.Thread(target=self.startProcessing,
+                #                            args=(track,))
+                # _thread.start()
+                self.__tracks[track] = asyncio.ensure_future(
+                    self.stream_consume(track, self.gsdbs, self.target, self.onframe))
+
+
+    async def stream_consume(self, track, gsdbs, target, onframe):
+        while True:
+            try:
+                frame = await track.recv()
+                await self.broadcastthread.write(frame)
+            except MediaStreamError:
+                return
+
+    async def stop(self):
+        """
+        Stop discarding media.
+        """
+        for task in self.__tracks.values():
+            if task is not None:
+                task.cancel()
+        self.__tracks = {}
+
+
+
